/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2023  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#include <assert.h>

#include "databaseitem.h"

TDatabaseItem::TDatabaseItem(void)
{
}

TDatabaseItem::TDatabaseItem(
	const TDatabaseItem					&rhs)
{
	if(&rhs != this)
	{
		d_make = rhs.d_make;
		d_model = rhs.d_model;
		d_option = rhs.d_option;
		d_standard_type = rhs.d_standard_type;
		
		d_specification_items = rhs.d_specification_items;
	}
}

TDatabaseItem& TDatabaseItem::operator=(
	const TDatabaseItem					&rhs)
{
	if(&rhs != this)
	{
		d_make = rhs.d_make;
		d_model = rhs.d_model;
		d_option = rhs.d_option;
		d_standard_type = rhs.d_standard_type;

		d_specification_items = rhs.d_specification_items;
	}
	
	return *this;
}

TDatabaseItem::~TDatabaseItem(void)
{
}

TDatabaseItem::TSpecification_Item TDatabaseItem::Specification_Item(
	const int							index) const
{
	assert(static_cast<unsigned int>(index) < d_specification_items.size());
	
	return d_specification_items[index];
}

QString TDatabaseItem::Specification_Expression(
	const QString						&component,
	const TExpressionItem::TUnits		units) const
{
	std::vector<TSpecification_Item>::const_iterator iter;
	
	for(iter = d_specification_items.begin();iter != d_specification_items.end();++iter)
	{
		if(component.compare((*iter).component) == 0)
		{
			return (*iter).expression_item.Expression(units);
		}
	}
	
	return QString();
}

TDatabaseItem::TSpecification_Item_Source TDatabaseItem::Specification_Source(
	const QString						&component) const
{
	std::vector<TSpecification_Item>::const_iterator iter;
	
	for(iter = d_specification_items.begin();iter != d_specification_items.end();++iter)
	{
		if(component.compare((*iter).component) == 0)
		{
			return (*iter).source;
		}
	}
	
	return TDatabaseItem::SOURCE_MANUFACTURER;
}

void TDatabaseItem::Set_Make(
	const QString						&s)
{
	if(s.compare(d_make) != 0)
	{
		d_specification_items.clear();
	}

	d_make = s;
}

void TDatabaseItem::Set_Model(
	const QString						&s)
{
	if(s.compare(d_model) != 0)
	{
		d_specification_items.clear();
	}
	
	d_model = s;
}

void TDatabaseItem::Set_Option(
	const QString						&s)
{
	if(s.compare(d_option) != 0)
	{
		d_specification_items.clear();
	}

	d_option = s;
}

void TDatabaseItem::Set_Standard_Type(
	const QString						&s)
{
	if(s.compare(d_standard_type) != 0)
	{
		d_specification_items.clear();
	}
	
	d_standard_type = s;
}

void TDatabaseItem::Clear_Specification_Items(void)
{
	d_specification_items.clear();
}

void TDatabaseItem::Clear_Estimated_Specification_Items(void)
{
	std::vector<TSpecification_Item>	new_items;
	std::vector<TSpecification_Item>::const_iterator iter;
	
	for(iter=d_specification_items.begin();iter != d_specification_items.end();++iter)
	{
		if((*iter).source == TDatabaseItem::SOURCE_MANUFACTURER)
		{
			new_items.push_back(*iter);
		}
	}
	
	d_specification_items = new_items;
}

void TDatabaseItem::Add_Specification_Item(
	const TSpecification_Item			&item)
{
	d_specification_items.push_back(item);
}

void TDatabaseItem::Clean_Strings(void)
{
	this->Clean_String(&d_make);
	this->Clean_String(&d_model);
	this->Clean_String(&d_option);
	this->Clean_String(&d_standard_type);
}

QString TDatabaseItem::Clean_String(
	const QString						&s)
{
	QString								clean(s);
	
	TDatabaseItem::Clean_String(&clean);
	
	return clean;
}

void TDatabaseItem::Clean_String(
	QString								* const str)
{
	assert(str);
	
	str->remove('\'');
	str->remove('\"');
	str->remove('%');
	str->remove('*');
	str->remove('[');
	str->remove(']');
	str->remove('^');
	str->remove('\\');
	str->remove('/');
	str->remove(',');
	str->remove(':');
}



