/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2023  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#ifndef DATABASEITEMHEADERFILE
#define DATABASEITEMHEADERFILE

#include <QString>
#include <QDataStream>
#include <vector>

#include "expressionitem.h"

class TDatabaseItem
{
public:
	
enum TSpecification_Item_Source
{
	SOURCE_MANUFACTURER=0,
	SOURCE_ESTIMATED
};
	
struct TSpecification_Item
{
	QString								component;
	TExpressionItem						expression_item;
	QString								description;
	int									expression_types;
	TSpecification_Item_Source			source;
};

// CREATORS
	TDatabaseItem(void);
	TDatabaseItem(const TDatabaseItem&);
	TDatabaseItem& operator=(const TDatabaseItem&);
	~TDatabaseItem(void);
	
// ACCESSORS
	QString Make(void) const {return d_make;}
	QString Model(void) const  {return d_model;}
	QString Option(void) const {return d_option;}
	QString Standard_Type(void) const {return d_standard_type;}
	
	int Specification_Items_Count(void) const {return static_cast<int>(d_specification_items.size());}
	TSpecification_Item Specification_Item(const int index) const;
	
	QString Specification_Expression(const QString &component,const TExpressionItem::TUnits units) const;
	TSpecification_Item_Source Specification_Source(const QString &component) const;
	
// MANIPULATORS
	
	// all Set_ options clear specification items if different
	void Set_Make(const QString &s);
	void Set_Model(const QString &s);
	void Set_Option(const QString &s);
	void Set_Standard_Type(const QString &s);
	
	void Clear_Specification_Items(void);
	void Clear_Estimated_Specification_Items(void);
	void Add_Specification_Item(const TSpecification_Item &item);
	
	void Clean_Strings(void);								// removes characters that would be problematic
	static QString Clean_String(const QString &s);			// removes characters that would be problematic
	
private:
	
	
	QString								d_make;
	QString								d_model;
	QString								d_option;
	QString								d_standard_type;
	
	std::vector<TSpecification_Item>	d_specification_items;
	
	static void Clean_String(QString * const str);
	
// NOT IMPLEMENTED
};

#endif
