/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2023  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#include <QApplication>
#include <QFrame>
#include <QHBoxLayout>
#include <QPushButton>
#include <QRadioButton>
#include <QSpacerItem>
#include <QVBoxLayout>

#include "exportoptionsdialog.h"

TExportOptionsDialog::TExportOptionsDialog(
	const QWidget						*parent,
	const Qt::WindowFlags				flags)
:QDialog(const_cast<QWidget*>(parent),flags)
{
	QFrame								*separator_hline;
	QHBoxLayout							*button_hlayout;
	QPushButton							*cancel_button;
	QPushButton							*continue_button;
	QSpacerItem							*button_hspacer;
	QSpacerItem							*dialog_vspacer;
	QVBoxLayout							*dialog_vlayout;


	this->resize(400,144);

	dialog_vlayout = new QVBoxLayout(this);

	d_all_specifications_radio = new QRadioButton(this);
	d_all_specifications_radio->setChecked(true);
	dialog_vlayout->addWidget(d_all_specifications_radio);

	d_selected_specifications_radio = new QRadioButton(this);
	dialog_vlayout->addWidget(d_selected_specifications_radio);

	separator_hline = new QFrame(this);
	separator_hline->setFrameShape(QFrame::HLine);
	separator_hline->setFrameShadow(QFrame::Sunken);
	dialog_vlayout->addWidget(separator_hline);

	dialog_vspacer = new QSpacerItem(0,0,QSizePolicy::Minimum,QSizePolicy::Expanding);
	dialog_vlayout->addItem(dialog_vspacer);

	button_hlayout = new QHBoxLayout();

	button_hspacer = new QSpacerItem(0,0,QSizePolicy::Expanding,QSizePolicy::Minimum);
	button_hlayout->addItem(button_hspacer);

	cancel_button = new QPushButton(this);
	cancel_button->setAutoDefault(false);
	button_hlayout->addWidget(cancel_button);

	continue_button = new QPushButton(this);
	continue_button->setDefault(true);
	button_hlayout->addWidget(continue_button);
	dialog_vlayout->addLayout(button_hlayout);

	this->setWindowTitle(QStringLiteral("Export Options"));
	d_all_specifications_radio->setText(QStringLiteral("All Specification Data"));
	d_selected_specifications_radio->setText(QStringLiteral("Selected Specifications"));
	cancel_button->setText(QStringLiteral("Cancel"));
	continue_button->setText(QStringLiteral("Continue"));
	
	connect(cancel_button,&QPushButton::clicked,this,&TExportOptionsDialog::reject);
	connect(continue_button,&QPushButton::clicked,this,&TExportOptionsDialog::accept);
}

TExportOptionsDialog::~TExportOptionsDialog(void)
{
}

TExportOptionsDialog::TExportType TExportOptionsDialog::Export_Type(void) const
{
	TExportOptionsDialog::TExportType	export_type(TExportOptionsDialog::EXPORT_ALL_SPECIFICATIONS);
	
	if(d_selected_specifications_radio->isChecked())
	{
		export_type = TExportOptionsDialog::EXPORT_SELECTED_SPECIFICATIONS;
	}
	
	return export_type;
}

