/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2023  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#ifndef EXPRESSIONITEMHEADERFILE
#define EXPRESSIONITEMHEADERFILE

#include <QString>

class TExpressionItem
{
public:
	
// EXPRESSION_VALUE = 0.001
// EXPRESSION_VALUE_LENGTH = 0.001/700
// EXPRESSION_CONST_VALUE_LENGTH = 0.001+0.002L/700
// EXPRESSION_CONST_VALUE_LENGTH_LIMIT = 0.001+0.002L/700 | 0.1
// EXPRESSION_VALUE_LENGTH_TEMPERATURE = (0.005+0.05Td)/1000
// EXPRESSION_CONST_VALUE_LENGTH_TEMPERATURE = 0.005+0.05Td+(0.005+0.2Td)L/1000
// EXPRESSION_VALUE_TEMPERATURE = 20 C
	
	static const int					EXPRESSION_UNKNOWN									= 0x00000000;
	static const int					EXPRESSION_VALUE									= 0x00000001;
	static const int					EXPRESSION_VALUE_LENGTH								= 0x00000002;
	static const int					EXPRESSION_CONST_VALUE_LENGTH						= 0x00000004;
	static const int					EXPRESSION_CONST_VALUE_LENGTH_LIMIT					= 0x00000008;
	static const int					EXPRESSION_VALUE_LENGTH_TEMPERATURE					= 0x00000010;
	static const int					EXPRESSION_CONST_VALUE_LENGTH_TEMPERATURE			= 0x00000020;
	static const int					EXPRESSION_VALUE_TEMPERATURE_CELSIUS				= 0x00000040;
	
enum TUnits
{
	UNITS_MM = 0,
	UNITS_UM
};
	
// CREATORS
	TExpressionItem(void);
	TExpressionItem(const TExpressionItem&);
	TExpressionItem& operator=(const TExpressionItem&);
	~TExpressionItem(void);
	
// ACCESSORS
	
	QString Expression(const TUnits units) const;
	
	int Expression_Type(void) const {return d_expression_type;}
	
	int Expression_Value_Count(void);
	double Expression_Value(const int index,const int units) const;
	
	
// MANIPULATORS
	int Set_Expression(const QString &expression,const TUnits units);	// returns expression type

private:
	
	static const int					EXPRESSION_COMPONENT_SIZE	= 5;
	
	int									d_expression_type;
	double								d_expression_components[EXPRESSION_COMPONENT_SIZE];
	
	void Evaluate_Expression(const QString &expression);
		
};


#endif
