/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2023  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#ifndef IMPORT_EXPORTHEADERFILE
#define IMPORT_EXPORTHEADERFILE

#include <QThread>
#include <QString>

class TDatabase;

class TImportExportThread : public QThread
{
	Q_OBJECT
public:
	
enum TExecutionMode
{
	MODE_EXPORT = 0,
	MODE_IMPORT
};
	
// CREATORS
	TImportExportThread(const QObject *parent=0);
	virtual ~TImportExportThread(void);

// ACCESSORS
	QString Last_Error(void) const {return d_last_error;}
	
	TExecutionMode Execution_Mode(void) const {return d_execution_mode;}
	bool Error_State(void) const {return d_error_state;}
	
// MANIPULATORS
	void Set_Database(TDatabase * const database) {d_database = database;}
	void Set_Export_Mode(void){d_execution_mode = MODE_EXPORT;}
	void Set_Import_Mode(void){d_execution_mode = MODE_IMPORT;}
	
	void Set_File_Name(const QString &s) {d_file_name = s;}
	
	void Clear_Export_Make_List(void) {d_export_make_list.clear();}
	void Set_Export_Make_List(const QStringList &export_list) {d_export_make_list = export_list;}
	
signals:
	void Update_Progress(int,int);				// value, range
	void Update_Progress_Text(const QString&);	// description of sequence
	
private:
	
	TDatabase							*d_database;
	
	TExecutionMode						d_execution_mode;
	QString								d_file_name;
	QStringList							d_export_make_list;
	
	mutable bool						d_error_state;
	mutable QString						d_last_error;
	
	virtual void run(void);
	
	void Export_Database(void);
	void Import_Database(void);


// NOT IMPLEMENTED
	TImportExportThread(const TImportExportThread&);
	TImportExportThread& operator=(const TImportExportThread&);
};


#endif
