/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2023  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////


#ifndef SPECIFICATIONEDITORDIALOGHEADERFILE
#define SPECIFICATIONEDITORDIALOGHEADERFILE

#include <QDialog>
#include <vector>

class QLineEdit;
class QLabel;
class QPushButton;
class QTableWidget;
class QTableWidgetItem;
class TDatabase;

class TSpecificationEditorDialog : public QDialog
{
Q_OBJECT

public:
	
struct TEntryItem
{
	QString								standard;
	QString								component;
	QString								expression;
	QString								description;
	int									expression_types;
	int									valid;
};

// CREATORS
	TSpecificationEditorDialog(const QWidget *parent=0, Qt::WindowFlags flags=Qt::WindowFlags());
	~TSpecificationEditorDialog(void);

// ACCESSORS
	QString Make(void) const;
	QString Model(void) const;
	QString Option(void) const;
	
	std::vector<TEntryItem> Specification_Entries(void);
	
// MANIPULATORS
	
	void Reset(TDatabase * const database,const QString &make,const QString &model,const QString &option,const std::vector<TEntryItem> &entry_items);

signals:

private slots:
	
	void Cell_Changed(int,int);			// row, column;
	void Identification_Changed(void);

private:
	QLineEdit							*d_make_edit;
	QLineEdit							*d_model_edit;
	QLineEdit							*d_option_edit;
	QLabel								*d_make_exists_label;
	QLabel								*d_model_exists_label;
	QLabel								*d_option_exists_label;
	QPushButton							*d_accept_button;
	QTableWidget						*d_specification_table;
	TDatabase							*d_database;
	
	std::vector<TEntryItem>				d_entry_items;
	
	void Create_Table_Columns(void);
	
	void Update_Status_Column(void);
	void Update_Row_Status(const int row);
	void Update_Accept_Button_Enable(void);
	void Update_Exist_Labels(void);
	

// NOT IMPLEMENTED
	TSpecificationEditorDialog(const TSpecificationEditorDialog&);
	TSpecificationEditorDialog& operator=(const TSpecificationEditorDialog&);
};

#endif
